<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Notices
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2021 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('_JEXEC') or die;

// Bibliotecas a importar
jimport('joomla.filesystem.folder');
jimport('noboss.util.fonts');
jimport('noboss.util.loadextensionassets');
jimport('noboss.util.url');

// Carrega helper do módulo.
JLoader::register('ModNobossnoticesHelper', __DIR__ . '/helper.php');

// Verifica se no boss library esta instalada: se ainda nao estiver, tenta instalar e se ainda nao der retorna false
if(!ModNobossnoticesHelper::checkLibraryInstallation()){
    return;
}

$app = JFactory::getApplication();
// pega o template vinculado a pagina
$tmpl = $app->getTemplate(true);
// pega os parametros do template
$tmplParams = $tmpl->params;
// pega a cor primaria setada nos parametros do template
$tmplPrimaryColor = $tmplParams->get('primary_color');
// pega a cor secundaria setada nos parametros do template
$tmplSecondaryColor = $tmplParams->get('secondary_color');

// Parametro com nome do modulo nao esta definido
if (!isset($module->name)){
    $module->name = str_replace('mod_', '', $module->module);
}
$moduleName = $module->name;
$extensionName = "mod_" . $module->name;

// Instancia objeto da classe para obter o diretorio da extensao
$assetsObject = new NoBossUtilLoadExtensionAssets("lib_noboss");
// Obtem diretorio da extensao
$extensionPath = $assetsObject->getDirectoryExtension(false);
// Carrega arquivo traducao para extensao especificada
JFactory::getLanguage()->load("lib_noboss", $extensionPath);

$doc = JFactory::getDocument();
$ds = DIRECTORY_SEPARATOR;

/*
 * TODO: na versao 2 lancada em mar/2020, foram criadas novos models, mas no codigo foi fixado tudo como model1 para que possam usar os mesmos campos. 
 * Se fosse mantida a logica normal, seria necessario duplicar subforms, models, etc. Nos arquivos ja foram removidos o nome 'model1', mas aqui no codigo
 * foi mantido para que dados nao sejam perdidos para usuarios que atualizarem a extensao.
 */
$theme = json_decode($params->get("theme"));
$theme = $theme->theme;

$item = $params->get('model1');
$item = (array)$item;
$item = reset($item);
$item = (object)$item;

// armazema estilo da seção, elemento mais externo do html 
$sectionStyle = "";
// armazema estilo da seção para o mobile, elemento mais externo do html 
$sectionStyleMobile = "";

// string com o nome da modal da área externa concatenado com o modelo selecionado 
$externalAreaXml = 'model1_external_area_customization';
// variável que armazena o objeto com os parâmetros da modal de área externa do tema selecionado  
$externalArea = json_decode($params->get($externalAreaXml));
// string com o nome da modal de itens concatenado com o modelo selecionado 
$itemsCustomizationXml = 'model1_items_customization';
// variável que armazena o objeto com os parâmetros da modal de itens do tema selecionado  
$itemsCustomization = json_decode($params->get($itemsCustomizationXml));

// define tamanho da área externa
if ($externalArea->external_area_display_mode){
	if(!empty($externalArea->external_area_width)){
		$sectionStyle .= 'margin-left: auto !important; margin-right: auto !important; width:' . $externalArea->external_area_width . '%;';
	}
    else{
        $sectionStyle .= 'width: 100%;';
    }
	if(!empty($externalArea->external_area_width_mobile)){
		$sectionStyleMobile .= 'margin-left: auto !important; margin-right: auto !important; width:' . $externalArea->external_area_width_mobile . '% !important; ';
	}
    else{
        $sectionStyleMobile .= 'width: 100%;';
    }
}

// verifica qual o modo de exibição
// 1: é manual, então exibe container
// 0: é full width 
if($externalArea->content_display_mode){
    $itemColumns = !empty($externalArea->content_columns) ? "nb-lg-{$externalArea->content_columns} nb-md-{$externalArea->content_columns} nb-sm-{$externalArea->content_columns} nb-xs-12" : "";
}

// armazena o estilo do espaçamento interno na variável que é colocada no elemento mais externo
$sectionStyle .= ' padding: ' . implode(' ', $externalArea->external_area_inner_space) . '; ';
// armazena o estilo do espaçamento interno para o mobile na variável que é colocada no elemento mais externo
$sectionStyleMobile .= 'padding: ' . implode(' ', $externalArea->external_area_inner_space_mobile) . ' !important; ';
// armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
$sectionStyle .= ' margin: ' . implode(' ', $externalArea->external_area_outer_space) . '; ';
// armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
$sectionStyleMobile .= 'margin: ' . implode(' ', $externalArea->external_area_outer_space_mobile) . ' !important;';

$overlap = $params->get('overlap');

$stylePosition = $overlap ? 'absolute; top: 0; z-index: 9999999; left: 50%;
transform: translate(-50%, 0%);' : 'relative';

$sectionStyle .= " position: {$stylePosition}; ";
if(isset($externalArea->show_shadow) && $externalArea->show_shadow){
    $sectionStyle .= " box-shadow: 0 4px 5px 0 rgba(0,0,0,0.14), 0 1px 10px 0 rgba(0,0,0,0.12), 0 2px 4px -1px rgba(0,0,0,0.3); ";
}

// cor de fundo da área externa
// Armazena o tipo de fundo da area externa (cor ou gradiente)
$backgroundType = $externalArea->external_area_background_type;

// Se o tipo de fundo for "cor"
if($backgroundType == "background-color" && !empty($externalArea->external_area_background_color)){
    // pega a cor definida no modulo ou a cor primaria do template
    $externalArea->external_area_background_color = !empty($externalArea->external_area_background_color) ? $externalArea->external_area_background_color : $tmplPrimaryColor;
    // Armazena essa cor ao estilo de fundo da secao
    $sectionStyle .= "background-color: {$externalArea->external_area_background_color};";
    // Seta a cor como padrao para texto dos botoes (qnd usuario nao definir cor propria na personalizacao do botao)
    $buttonsColorDefault = $externalArea->external_area_background_color;
}elseif($backgroundType == "background-gradient"){
    // Se o tipo for gradiente, acresenta o CSS de gradiente ao estilo da seção
    $gradient1 = $externalArea->external_area_gradient_filter_1;
    $gradient2 = $externalArea->external_area_gradient_filter_2;
    $sectionStyle .= "background: {$gradient2}; ";
    $sectionStyle .= "background: -webkit-linear-gradient(to right, {$gradient1}, {$gradient2}); "; 
    $sectionStyle .= "background: linear-gradient(to right, {$gradient1}, {$gradient2}); ";
    // Seta a cor como padrao para texto dos botoes (qnd usuario nao definir cor propria na personalizacao do botao)
    $buttonsColorDefault = $gradient1;
}

$borderRadius = !empty($itemsCustomization->border_radius) ? "border-radius: {$itemsCustomization->border_radius}px;" : "";
// valida o modelo para definir os estilos de fundo dos itens 
$itemsCustomization->box_background_color = !empty($itemsCustomization->box_background_color) ? 'padding:15px; background-color: '. $itemsCustomization->box_background_color .'; ' : 'padding:15px; background-color: '. $tmplPrimaryColor .'; ';
// pega a cor definida no modulo ou a cor primaria do template
$itemsCustomization->content_background_color = !empty($itemsCustomization->content_background_color) ? $itemsCustomization->content_background_color : $tmplPrimaryColor;
$itemsCustomization->content_background_color = !empty($itemsCustomization->content_background_color) ? 'background-color: '. $itemsCustomization->content_background_color .'; ' : ''; 
$itemStyle = "";
$itemStyleMobile = "";
$itemStyle .= !empty($itemsCustomization->items_inner_space) ? "padding: " . implode(' ', $itemsCustomization->items_inner_space) . "; " : "";
$itemStyle .= !empty($itemsCustomization->items_outer_space) ? "margin: " . implode(' ', $itemsCustomization->items_outer_space) . "; " : "";
$itemStyleMobile .= !empty($itemsCustomization->items_inner_space_mobile) ? "padding: " . implode(' ', $itemsCustomization->items_inner_space_mobile) . " !important; " : "";
$itemStyleMobile .= !empty($itemsCustomization->items_outer_space_mobile) ? "margin: " . implode(' ', $itemsCustomization->items_outer_space_mobile) . " !important; " : "";

if(isset($itemsCustomization->show_close_button) && $itemsCustomization->show_close_button){
    $closeButtonColor = 'color: '.$itemsCustomization->close_button_color.'; ';
}

// Alinhamento dos botoes e cupons conforme definicao para textos no desktop
switch ($itemsCustomization->texts_alignment) {
    case 'right':
        $buttonAndCuponPosition .= "margin-left: auto;";
        break;
    case 'left':
        break;
    case 'center':
        $buttonAndCuponPosition = "margin-left: auto !important; margin-right: auto !important;";
        break;
}

// Alinhamento dos textos no mobile
$textAlignStyleMobile = "";
switch ($itemsCustomization->texts_alignment_mobile) {
    case 'right':
        $textAlignStyleMobile .= "text-align: right; align-items: flex-end;";
        break;
    case 'left':
        $textAlignStyleMobile .= "text-align: left; align-items: flex-start;";
        break;
    case 'center':
        $textAlignStyleMobile .= "text-align: center; align-items: center;";
        // Cria tb estilo para alinhar ao centro os botoes e cupons
        $buttonAndCuponPositionMobile = "margin-left: auto !important; margin-right: auto !important;";
        break;
}

// Parâmetros para título dos itens
$itemsTitleTagHtml = $itemsCustomization->title_tag_html;
$itemsTitleStyle = "";
$itemsTitleStyle .= NoBossUtilFonts::importNobossfontlist($itemsCustomization->title_font);
$itemsTitleStyle .= " text-transform: " . $itemsCustomization->title_transform . ";";
// pega a cor definida no modulo ou a cor primaria do template
$itemsCustomization->title_color = !empty($itemsCustomization->title_color) ? $itemsCustomization->title_color : $tmplPrimaryColor;
$itemsTitleStyle .= " color: " . $itemsCustomization->title_color . ";";
$itemsTitleSize = $itemsCustomization->title_size;
if(!empty($itemsTitleSize)){
	$itemsTitleSizeEm = $itemsTitleSize/16;
	$itemsTitleStyle .= " font-size: {$itemsTitleSize}px; font-size: {$itemsTitleSizeEm}em;";
}
$itemsTitleStyleMobile = "";
if(isset($itemsCustomization->title_size_mobile)){
	$itemsTitleSizeMobile = $itemsCustomization->title_size_mobile;
	$itemsTitleSizeMobileEm = $itemsTitleSizeMobile/16;
	$itemsTitleStyleMobile = " font-size: {$itemsTitleSizeMobile}px; font-size: {$itemsTitleSizeMobileEm}em !important;";
}
if(isset($itemsCustomization->title_space)){
	$itemsTitleStyle .= " padding: ".implode(" ", $itemsCustomization->title_space).';';
}
if(isset($itemsCustomization->title_space_mobile)){
	$itemsTitleStyleMobile .= " padding: ".implode(" ", $itemsCustomization->title_space_mobile).' !important;';
}

// Parâmetros para texto de apoio dos itens
$itemsContentStyle = "";
$itemsContentStyle .= NoBossUtilFonts::importNobossfontlist($itemsCustomization->content_font);
$itemsContentStyle .= " text-transform: " . $itemsCustomization->content_transform . ";";

$itemsContentSize = $itemsCustomization->content_size;
if(!empty($itemsContentSize)){
    $itemsContentSizeEm = $itemsContentSize/16;
    $itemsContentStyle .= " font-size: {$itemsContentSize}px; font-size: {$itemsContentSizeEm}em;";
}
$itemsContentStyleMobile = "";
if(isset($itemsCustomization->content_size_mobile)){
    $itemsContentSizeMobile = $itemsCustomization->content_size_mobile;
    $itemsContentSizeMobileEm = $itemsContentSizeMobile/16;
    $itemsContentStyleMobile = " font-size: {$itemsContentSizeMobile}px; font-size: {$itemsContentSizeMobileEm}em !important;";
}
if(isset($itemsCustomization->content_space)){
    $itemsContentStyle .= " padding: ".implode(" ", $itemsCustomization->content_space).';';
}
if(isset($itemsCustomization->content_space_mobile)){
    $itemsContentStyleMobile .= " padding: ".implode(" ", $itemsCustomization->content_space_mobile).' !important;';
}

$ruleDisplay = $params->get('rule_display');
$displayInterval = $params->get('display_interval');

// Links
$item->links = new \stdClass();

if(!empty($item->show_link)){
    $item->links->link1 = json_decode($item->link1_customization);
    $linksClass = "";
    if($item->buttons_below_text && !empty($item->buttons_position)){
        $linksClass = "{$module->name}-links--{$item->buttons_position}";
    }
}

if((!empty($item->show_link)) && (!empty($item->show_link2))){
    $item->links->link2 = json_decode($item->link2_customization);
}
$count = 0;
$item->links_class = "";
foreach ($item->links as $key => $link) {
    $count++;
    // Valida se o tipo de link é externo 
    if($link->link_option == "external") {
        $link->link_url = $link->link_external;
    // Valida se o tipo de link é interno, ou seja, um item de menu 
    } else if($link->link_option == "internal") {
        $link->link_url = NoBossUtilUrl::getUrlItemMenu($link->link_internal);
    }
    $link->link_target = $link->link_target ? "_blank" : "_self";
    if($item->show_link){
        $link->button_style = "";
        $link->button_style_mobile = "";

        // armazena o estilo do botão para o hover
        $link->button_style_hover = "";
        
        // Cor do texto do botao (se nao definido, pega a cor de fundo das notificacoes)
        $link->buttons_text_color = !empty($link->buttons_text_color) ? $link->buttons_text_color : $buttonsColorDefault;
        // Cor do texto no hover do botao (se nao definido, pega a cor de fundo das notificacoes)
        $link->buttons_hover_text_color = !empty($link->buttons_hover_text_color) ? $link->buttons_hover_text_color : $buttonsColorDefault;
        // pega a cor definida no modulo ou a cor primaria do template
        $link->buttons_background_color = !empty($link->buttons_background_color) ? $link->buttons_background_color : $tmplPrimaryColor;
        // pega a cor definida no modulo ou a cor primaria do template
        $link->buttons_border_color = !empty($link->buttons_border_color) ? $link->buttons_border_color : $tmplPrimaryColor;
        // pega a cor definida no modulo ou a cor secundaria do template
        $link->buttons_background_hover_color = !empty($link->buttons_background_hover_color) ? $link->buttons_background_hover_color : $tmplSecondaryColor;
        // pega a cor definida no modulo ou a cor secundaria do template
        $link->buttons_hover_border_color = !empty($link->buttons_hover_border_color) ? $link->buttons_hover_border_color : $tmplSecondaryColor;
        // Verifica tipo de link entre as opções abaixo e retorna o estilo para ser colocado no link na tmpl
        switch ($link->buttons_style) {
            // Botão quadrado
            case 'squared-button':
                $link->button_style = "color: {$link->buttons_text_color}; background-color: {$link->buttons_background_color};";
                $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                break;
            // Botão arredondado
            case 'rounded-button':
                $link->button_style = "color: {$link->buttons_text_color}; background-color: {$link->buttons_background_color}; border-radius: {$link->buttons_border_radius_size}px;";
                $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                break;
            // Botão transparente quadrado
            case 'ghost-squared-button':
                $link->button_style = "background-color: transparent; border: 2px solid; color: {$link->buttons_text_color}; border-color: {$link->buttons_border_color};";
                $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; border-color: {$link->buttons_hover_border_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                break;
            // Botão transparente arredondado
            case 'ghost-rounded-button':
                $link->button_style = "background-color: transparent; border: 2px solid; color: {$link->buttons_text_color}; border-color: {$link->buttons_border_color}; border-radius: {$link->buttons_border_radius_size}px;";
                $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; border-color: {$link->buttons_hover_border_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                break;
            default:
                $link->button_style = "color: {$link->buttons_text_color};";
                break;
        }

        $link->button_style .= NoBossUtilFonts::importNobossfontlist($link->buttons_font);
        
        $link->button_style .= " text-transform: " . $link->buttons_text_transform . ";";
        
        // Font size do botao
        $buttonsSize = $link->buttons_text_size;
        if(!empty($buttonsSize)){
            $buttonsSizeEm = $buttonsSize/16;
            $link->button_style .= " font-size: {$buttonsSize}px; font-size: {$buttonsSizeEm}em;";
        }
       
        // Font size do botao no mobile
        $buttonsSizeEmMobile = $link->buttons_text_size_mobile/16;
        $link->button_style_mobile .= " font-size: {$link->buttons_text_size_mobile}px !important; font-size: {$buttonsSizeEmMobile}em !important;";

        // Espacamentos do botao
        $link->button_style .= isset($link->buttons_inner_space) ? ' padding: '.implode(' ', $link->buttons_inner_space).';' : ' padding: 0.75em 2em;';
        $link->button_style .= isset($link->buttons_outer_space) ? ' margin: '.implode(' ', $link->buttons_outer_space).';' : '';
        
        // Espacamentos do botao no mobile
        $link->button_style_mobile .= isset($link->buttons_inner_space_mobile) ? ' padding: '.implode(' ', $link->buttons_inner_space_mobile).' !important;' : '';
        $link->button_style_mobile .= isset($link->buttons_outer_space_mobile) ? ' margin: '.implode(' ', $link->buttons_outer_space_mobile).' !important;' : '';
    }
}

$sectionClasses = "";

$displayImage = $params->get('display_image');
$displayCoupon = $params->get('display_coupon');
$displayCounter = $params->get('display_counter');


// Definida exibicao de cupom de desconto
if($displayCoupon){
    $sectionClasses .= $module->name."--discount-coupon";
    $discountCouponParams = $params->get("model1_discount_coupon");
    $discountCouponParams = (array)$discountCouponParams;
    $discountCouponParams = reset($discountCouponParams);
    $discountCouponParams = (object)$discountCouponParams;

    $discountCouponCustomization = json_decode($discountCouponParams->discount_coupon_customization);

    $discountCouponStyle = "";
    $discountCouponStyleMobile = "";

    if(isset($discountCouponCustomization->discount_coupon_font)){
        $discountCouponStyle .= NoBossUtilFonts::importNobossfontlist($discountCouponCustomization->discount_coupon_font);
    }

    if(isset($discountCouponCustomization->discount_coupon_transform)){
        $discountCouponStyle .= " text-transform: " . $discountCouponCustomization->discount_coupon_transform . ";";
    }
    $discountCouponStyle .= " color: ".$discountCouponCustomization->discount_coupon_color."; ";
    $discountCouponStyle .= " background-color: ".$discountCouponCustomization->discount_coupon_background_color."; ";
    
    // Espacamento interno do cupom de desconto
    if(isset($discountCouponCustomization->discount_coupon_inner_space)){
        $discountCouponStyle .= " padding: ".implode(" ", $discountCouponCustomization->discount_coupon_inner_space).';';
    }

    // Espacamento interno do cupom de desconto no mobile
    if(isset($discountCouponCustomization->discount_coupon_inner_space_mobile)){
        $discountCouponStyleMobile .= " padding: ".implode(" ", $discountCouponCustomization->discount_coupon_inner_space_mobile).' !important;';
    }

    // Espacamento externo do cupom de desconto
    if(isset($discountCouponCustomization->discount_coupon_external_space)){
        $discountCouponStyle .= " margin: ".implode(" ", $discountCouponCustomization->discount_coupon_external_space).';';
    }
    // Espacamento externo do cupom de desconto no mobile
    if(isset($discountCouponCustomization->discount_coupon_external_space)){
        $discountCouponStyleMobile .= " margin: ".implode(" ", $discountCouponCustomization->discount_coupon_external_space_mobile).' !important;';
    }

    // Font size do cupom de desconto
    if(isset($discountCouponCustomization->discount_coupon_size)){
        $discountCouponSize = $discountCouponCustomization->discount_coupon_size;
    }
    if(!empty($itemsContentSize) && isset($discountCouponSize)){
        $discountCouponSizeEm = $discountCouponSize/16;
        $discountCouponStyle .= " font-size: {$discountCouponSize}px; font-size: {$discountCouponSizeEm}em;";
    }

    // Font size do cupom de desconto no mobile
    if(isset($discountCouponCustomization->discount_coupon_size_mobile)){
        $discountCouponSizeMobile = $discountCouponCustomization->discount_coupon_size_mobile;
        $discountCouponSizeMobileEm = $discountCouponSizeMobile/16;
        $discountCouponStyleMobile .= " font-size: {$discountCouponSizeMobile}px; font-size: {$discountCouponSizeMobileEm}em !important;";
    }

    // Borda do cupom de desconto
    if(isset($discountCouponCustomization->show_discount_coupon_border) && $discountCouponCustomization->show_discount_coupon_border){
        $discountCouponBorderColor = $discountCouponCustomization->discount_coupon_border_color;
        $discountCouponBorderStyle = $discountCouponCustomization->discount_coupon_dashed_border ? 'dashed' : 'solid';
        $discountCouponStyle .= " border: ".$discountCouponBorderColor." 1px ".$discountCouponBorderStyle."; ";
    }
}

// Definida exibicao de contador
if($displayCounter){
    $sectionClasses .= $module->name."--counter";
    $counterParams = $params->get("model1_counter");
    $counterParams = (array)$counterParams;
    $counterParams = reset($counterParams);
    $counterParams = (object)$counterParams;

    $counterCustomization = (!empty($counterParams->counter_customization)) ?   
    json_decode($counterParams->counter_customization) : '';

    $nowDate = date('Y-m-d H:i:s');
    if ((!empty($counterParams->final_date)) && (($counterParams->final_date != '') && ($counterParams->final_date != '0000-00-00 00:00:00')) &&
    (strtotime($counterParams->final_date) >= strtotime($nowDate))){
        $counterFinalDate = $counterParams->final_date;
    }
    // Data do contador expirou! Nao exibe o modulo
    else{
        return;
    }

    $counterStyle = "";
    $counterStyleNumber = "";
    $counterTextsColor = " color: ".$counterCustomization->counter_texts_color."; ";
    $counterStyle .= NoBossUtilFonts::importNobossfontlist($counterCustomization->counter_font);
    
    // Cor dos numeros do contador (caso nao seja definido, pega a cor de fundo da notificacao)
    $counterStyleNumber .= !empty($counterCustomization->counter_numbers_color) ? " color: {$counterCustomization->counter_numbers_color};" : " color: {$buttonsColorDefault};";


    $counterStyleNumber .= " background-color: ".$counterCustomization->counter_background_color."; ";
    if(isset($counterCustomization->show_counter_border) && $counterCustomization->show_counter_border){
        $discountCouponBorderColor = $counterCustomization->counter_border_color;
        $discountCouponBorderStyle = $counterCustomization->counter_dashed_border ? 'dashed' : 'solid';
        $counterStyleNumber .= " border: ".$discountCouponBorderColor." 1px ".$discountCouponBorderStyle."; ";

        if(isset($counterCustomization->counter_rounded_border)){
            $counterStyleNumber .= " border-radius: ".$counterCustomization->counter_border_radius_size."px; ";
        }
    }
    
    // Font size do contador
    $counterFontSize = $counterCustomization->counter_size;
    if(!empty($counterFontSize)){
        $counterFontSizeEm = $counterFontSize/16;
        $counterStyle .= " font-size: {$counterFontSize}px; font-size: {$counterFontSizeEm}em;";
    }

    // Font size do contador no mobile
    $counterStyleMobile = "";
    if(isset($counterCustomization->counter_size_mobile)){
        $counterFontSizeMobile = $counterCustomization->counter_size_mobile;
        $counterFontSizeMobileEm = $counterFontSizeMobile/16;
        $counterStyleMobile .= " font-size: {$counterFontSizeMobile}px; font-size: {$counterFontSizeMobileEm}em !important;";
    }

}

// Definida exibicao de imagem
if($displayImage){
    $sectionClasses .= $module->name."--image";
    $imageParams = $params->get("model1_image");
    $imageParams = (array)$imageParams;
    $imageParams = reset($imageParams);
    $imageParams = (object)$imageParams;

    $imageCustomization = json_decode($imageParams->image_customization);

    if(filter_var($imageParams->image, FILTER_VALIDATE_URL)) { 
        $imageParams->image =  " background-image: url('".$imageParams->image."'); ";
    }else{
        $imageParams->image =  " background-image: url('".JURI::root() . $imageParams->image."'); ";
    }

    $imageWidth = " width: ".$imageCustomization->image_max_width."px; ";

    $imageStyle = "";
    $imageStyleMobile = "";

    if(isset($imageCustomization->image_outer_space) && $imageCustomization->image_outer_space){
        $imageStyle = " margin: ".implode(" ", $imageCustomization->image_outer_space).';';
    } 

    if(isset($imageParams->image_display_mobile) && $imageParams->image_display_mobile){
        $imageStyleMobile = " margin: ".implode(" ", $imageCustomization->image_outer_space_mobile).' !important;';
    }else{
        $imageStyleMobile = " display: none; ";
    }

    if(!isset($imageParams->image_mobile_position)){
        $imageParams->image_mobile_position = 'bottom';
    }
}

// Define prefixo a ser utilizado na insercao de codigos inline para CSS e JS
$prefixCodeJsAndCss = "[module-id={$module->name}_{$module->id}]";

// Obtem informacoes de codigos JS e CSS a serem inseridos
$loadJs	 		= $params->get('load_js');
$loadCss 		= $params->get('load_css');
$overwritingJs	= (!empty($params->get('overwriting_js'))) ? rtrim($params->get('overwriting_js')) : '';
$overwritingCss	= (!empty($params->get('overwriting_css'))) ? rtrim($params->get('overwriting_css')) : '';

// Instancia objeto passando o nome da extensao com prefixo (ex: 'mod_nobossbanners')
$assetsObject = new NoBossUtilLoadExtensionAssets($extensionName, $prefixCodeJsAndCss);
// Adiciona arquivos e codigos JS (se definido para exibir)
$assetsObject->loadJs($loadJs, array('code' => $overwritingJs));
// Adiciona arquivos e codigos CSS (se definido para carregar)
$assetsObject->loadCss($loadCss, array('code' => $overwritingCss));
// renderiza template e estilo do modelo escolhido
require JModuleHelper::getLayoutPath($extensionName, 'style/default');
require JModuleHelper::getLayoutPath($extensionName, $params->get('layout', 'theme/default'));
